# pykalimux
This is a python script by which you can install Kali Nethunter (Kali Linux) in your termux application without rooted phone.

## Usage
### How To Use pykalimux
1. Install Dependencies In Termux `pkg update -y && pkg install git python -y`
2. Git Clone Repo `git clone https://github.com/RaynerSec/pykalimux`
3. Change Directory `cd pykalimux`
4. Run script `python install.py`
